pub type Result<T> = Result<T, ClockError>;Expand description
Convenience alias used throughout the crate and by consumers.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(ClockError),
}pub type Result<T> = Result<T, ClockError>;Convenience alias used throughout the crate and by consumers.
pub enum Result<T> {
Ok(T),
Err(ClockError),
}